﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
namespace WingAIDiagnosisService.Carotid.Utilities
{
    class Carotid3DStreamReader
    {
        private readonly Stream _stream;

        public Carotid3DStreamReader(Stream stream)
        {
            _stream = stream;
        }

        /// <summary>
        /// Read a int32 value from the stream.
        /// </summary>
        /// <returns></returns>
        public int ReadInt()
        {
            var data = new byte[sizeof(int)];
            _stream.Read(data, 0, sizeof(int));
            return BitConverter.ToInt32(data, 0);
        }

        /// <summary>
        /// Read a byte array from the stream.
        /// </summary>
        /// <returns></returns>
        public byte[] ReadBytes()
        {
            var size = ReadInt();
            var data = new byte[size];
            _stream.Read(data, 0, size);
            return data;
        }

        /// <summary>
        /// Read string from stream.
        /// </summary>
        /// <returns></returns>
        public string ReadString()
        {
            var dataLength = ReadInt();
            var data = new byte[dataLength];
            _stream.Read(data, 0, dataLength);
            return Encoding.Unicode.GetString(data, 0, data.Length);
        }

        /// <summary>
        /// Read a float value from the stream.
        /// </summary>
        /// <returns></returns>
        public float ReadFloat()
        {
            var data = new byte[sizeof(float)];
            _stream.Read(data, 0, sizeof(float));
            return BitConverter.ToSingle(data, 0);
        }
    }
}
