﻿using System.Drawing;

namespace WingAIDiagnosisService.Carotid.Utilities.DetectPlaque
{


    public class DetectPlaqueResult
    {
        /// <summary>
        /// Is more than one plaque
        /// </summary>
        public PlaqueCountType PlaqueCountType { get; set; }

        /// <summary>
        /// plaque type
        /// </summary>
        public PlaqueType PlaqueType { get; set; }

        /// <summary>
        /// plaque width
        /// </summary>
        public float PlaqueWidth { get; set; }

        /// <summary>
        /// plaque height
        /// </summary>
        public float PlaqueHeight { get; set; }


        /// <summary>
        /// Stenosis rate
        /// </summary>
        public float Stenosis { get; set; }

        public PlaquePostionType PlaquePostion { get; set; }

        //是否识别成功
        public bool IsSuccess { get; set; }

        public DetectPlaqueResult() { }

        public DetectPlaqueResult(bool isSuccess)
        {
            IsSuccess = isSuccess;
        }
        public DetectPlaqueResult(bool isSuccess, PlaqueCountType plaqueCountType)
        {
            IsSuccess = isSuccess;
            PlaqueCountType = plaqueCountType;
        }
        public DetectPlaqueResult(bool isSuccess, PlaqueCountType plaqueCountType, PlaqueType plaqueType, float plaqueWidth, float plaqueHeight, float stenosis)
        {
            IsSuccess = isSuccess;
            PlaqueCountType = plaqueCountType;
            PlaqueType = plaqueType;
            PlaqueWidth = plaqueWidth;
            PlaqueHeight = plaqueHeight;
            Stenosis = stenosis;
        }
    }


    public enum PlaqueType
    {
        SoftPlaque,
        HardPlaque
    }

    public enum PlaquePostionType
    {
        UpperIntima,
        LowerIntima
    }

    public enum PlaqueCountType
    {
        NoPlaque,
        OnePlaque,
        MultiPlaque
    }


    /// <summary>
    /// 斑块结构体
    /// </summary>
    public struct Plaque
    {

        //斑块的像素宽
        public int PlaquePixelWidth;
        //斑块的像素高
        public int PlaquePixelHeight;

        //斑块的宽
        public float PlaqueWidth;
        //斑块的高
        public float PlaqueHeight;
        //斑块的面积
        public float PlaqueArea;

        //斑块的轮廓
        public Point[] PlaqueEdgePoints;
        //斑块的外接矩阵
        public Rectangle ExternalRectangle;
        // 狭窄率
        public float Stenosis;
        //斑块类型
        public PlaqueType PlaqueType;
        //斑块位置类型
        public PlaquePostionType PlaquePostion;
    }

}
