using System.Collections.Generic;
using System.Linq;
using WingAIDiagnosisService.Carotid;
using WingInterfaceLibrary.Enum;

namespace WingAIDiagnosisService.Manage
{
    public class DiagnosisResult
    {
        public DiagnosisResult() { }
        public List<AIDiagnosisPerImageModel> PerImageResults { get; set; } = new List<AIDiagnosisPerImageModel>();

        public CarotidResult CarotidResult { get; set; }

        public DiagnosisConclusion DiagnosisConclusion { get; set; } = DiagnosisConclusion.Unrecognized;
        public List<DiagnosisOrganEnum> DiagnosisOrgans => GetDiagnosisOrgans(PerImageResults);

        private List<DiagnosisOrganEnum> GetDiagnosisOrgans(List<AIDiagnosisPerImageModel> results)
        {
            var diagnosisOrgans = new List<DiagnosisOrganEnum>();
            foreach (var imageResult in results)
            {
                foreach (var diagnosisResult in imageResult.DiagResultsForEachOrgan)
                {
                    diagnosisOrgans.Add((DiagnosisOrganEnum)diagnosisResult.Organ);
                }
            }
            return diagnosisOrgans.Distinct().ToList();
        }
    }

    public class CarotidResult
    {
        public CarotidResult() { }
        public CarotidScanType CarotidScanType { get; set; }
        public CarotidScanDirection CarotidScanDirection { get; set; }
        public string SurfaceFile { get; set; } = string.Empty;
        public string MdlFile { get; set; } = string.Empty;
        public List<MeasureImageFile> MeasureImageFiles { get; set; } = new List<MeasureImageFile>();
        public string MeasureResult { get; set; } = string.Empty;
    }

    public class MeasureImageFile
    {
        public MeasureImageFile() { }
        public CarotidAIImageType ImageType { get; set; }
        public string ImageFile { get; set; } = string.Empty;

    }
}